# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/orgpolicy/v1/orgpolicy.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/orgpolicy/v1/orgpolicy.proto",
    package="google.cloud.orgpolicy.v1",
    syntax="proto3",
    serialized_options=b"\n\035com.google.cloud.orgpolicy.v1B\016OrgPolicyProtoP\001ZBgoogle.golang.org/genproto/googleapis/cloud/orgpolicy/v1;orgpolicy\252\002\031Google.Cloud.OrgPolicy.V1\312\002\031Google\\Cloud\\OrgPolicy\\V1\352\002\034Google::Cloud::OrgPolicy::V1",
    serialized_pb=b'\n)google/cloud/orgpolicy/v1/orgpolicy.proto\x12\x19google.cloud.orgpolicy.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto"\x8b\x05\n\x06Policy\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x12\n\nconstraint\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\x0c\x12/\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x0blist_policy\x18\x05 \x01(\x0b\x32,.google.cloud.orgpolicy.v1.Policy.ListPolicyH\x00\x12I\n\x0e\x62oolean_policy\x18\x06 \x01(\x0b\x32/.google.cloud.orgpolicy.v1.Policy.BooleanPolicyH\x00\x12K\n\x0frestore_default\x18\x07 \x01(\x0b\x32\x30.google.cloud.orgpolicy.v1.Policy.RestoreDefaultH\x00\x1a\xfb\x01\n\nListPolicy\x12\x16\n\x0e\x61llowed_values\x18\x01 \x03(\t\x12\x15\n\rdenied_values\x18\x02 \x03(\t\x12J\n\nall_values\x18\x03 \x01(\x0e\x32\x36.google.cloud.orgpolicy.v1.Policy.ListPolicy.AllValues\x12\x17\n\x0fsuggested_value\x18\x04 \x01(\t\x12\x1b\n\x13inherit_from_parent\x18\x05 \x01(\x08"<\n\tAllValues\x12\x1a\n\x16\x41LL_VALUES_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LLOW\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02\x1a!\n\rBooleanPolicy\x12\x10\n\x08\x65nforced\x18\x01 \x01(\x08\x1a\x10\n\x0eRestoreDefaultB\r\n\x0bpolicy_typeB\xcc\x01\n\x1d\x63om.google.cloud.orgpolicy.v1B\x0eOrgPolicyProtoP\x01ZBgoogle.golang.org/genproto/googleapis/cloud/orgpolicy/v1;orgpolicy\xaa\x02\x19Google.Cloud.OrgPolicy.V1\xca\x02\x19Google\\Cloud\\OrgPolicy\\V1\xea\x02\x1cGoogle::Cloud::OrgPolicy::V1b\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_POLICY_LISTPOLICY_ALLVALUES = _descriptor.EnumDescriptor(
    name="AllValues",
    full_name="google.cloud.orgpolicy.v1.Policy.ListPolicy.AllValues",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ALL_VALUES_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ALLOW", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DENY", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=688,
    serialized_end=748,
)
_sym_db.RegisterEnumDescriptor(_POLICY_LISTPOLICY_ALLVALUES)


_POLICY_LISTPOLICY = _descriptor.Descriptor(
    name="ListPolicy",
    full_name="google.cloud.orgpolicy.v1.Policy.ListPolicy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="allowed_values",
            full_name="google.cloud.orgpolicy.v1.Policy.ListPolicy.allowed_values",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="denied_values",
            full_name="google.cloud.orgpolicy.v1.Policy.ListPolicy.denied_values",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="all_values",
            full_name="google.cloud.orgpolicy.v1.Policy.ListPolicy.all_values",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="suggested_value",
            full_name="google.cloud.orgpolicy.v1.Policy.ListPolicy.suggested_value",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="inherit_from_parent",
            full_name="google.cloud.orgpolicy.v1.Policy.ListPolicy.inherit_from_parent",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_POLICY_LISTPOLICY_ALLVALUES],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=497,
    serialized_end=748,
)

_POLICY_BOOLEANPOLICY = _descriptor.Descriptor(
    name="BooleanPolicy",
    full_name="google.cloud.orgpolicy.v1.Policy.BooleanPolicy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="enforced",
            full_name="google.cloud.orgpolicy.v1.Policy.BooleanPolicy.enforced",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=750,
    serialized_end=783,
)

_POLICY_RESTOREDEFAULT = _descriptor.Descriptor(
    name="RestoreDefault",
    full_name="google.cloud.orgpolicy.v1.Policy.RestoreDefault",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=785,
    serialized_end=801,
)

_POLICY = _descriptor.Descriptor(
    name="Policy",
    full_name="google.cloud.orgpolicy.v1.Policy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="google.cloud.orgpolicy.v1.Policy.version",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="constraint",
            full_name="google.cloud.orgpolicy.v1.Policy.constraint",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="etag",
            full_name="google.cloud.orgpolicy.v1.Policy.etag",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.orgpolicy.v1.Policy.update_time",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="list_policy",
            full_name="google.cloud.orgpolicy.v1.Policy.list_policy",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="boolean_policy",
            full_name="google.cloud.orgpolicy.v1.Policy.boolean_policy",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="restore_default",
            full_name="google.cloud.orgpolicy.v1.Policy.restore_default",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_POLICY_LISTPOLICY, _POLICY_BOOLEANPOLICY, _POLICY_RESTOREDEFAULT],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="policy_type",
            full_name="google.cloud.orgpolicy.v1.Policy.policy_type",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=165,
    serialized_end=816,
)

_POLICY_LISTPOLICY.fields_by_name["all_values"].enum_type = _POLICY_LISTPOLICY_ALLVALUES
_POLICY_LISTPOLICY.containing_type = _POLICY
_POLICY_LISTPOLICY_ALLVALUES.containing_type = _POLICY_LISTPOLICY
_POLICY_BOOLEANPOLICY.containing_type = _POLICY
_POLICY_RESTOREDEFAULT.containing_type = _POLICY
_POLICY.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_POLICY.fields_by_name["list_policy"].message_type = _POLICY_LISTPOLICY
_POLICY.fields_by_name["boolean_policy"].message_type = _POLICY_BOOLEANPOLICY
_POLICY.fields_by_name["restore_default"].message_type = _POLICY_RESTOREDEFAULT
_POLICY.oneofs_by_name["policy_type"].fields.append(
    _POLICY.fields_by_name["list_policy"]
)
_POLICY.fields_by_name["list_policy"].containing_oneof = _POLICY.oneofs_by_name[
    "policy_type"
]
_POLICY.oneofs_by_name["policy_type"].fields.append(
    _POLICY.fields_by_name["boolean_policy"]
)
_POLICY.fields_by_name["boolean_policy"].containing_oneof = _POLICY.oneofs_by_name[
    "policy_type"
]
_POLICY.oneofs_by_name["policy_type"].fields.append(
    _POLICY.fields_by_name["restore_default"]
)
_POLICY.fields_by_name["restore_default"].containing_oneof = _POLICY.oneofs_by_name[
    "policy_type"
]
DESCRIPTOR.message_types_by_name["Policy"] = _POLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Policy = _reflection.GeneratedProtocolMessageType(
    "Policy",
    (_message.Message,),
    {
        "ListPolicy": _reflection.GeneratedProtocolMessageType(
            "ListPolicy",
            (_message.Message,),
            {
                "DESCRIPTOR": _POLICY_LISTPOLICY,
                "__module__": "google.cloud.orgpolicy.v1.orgpolicy_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.orgpolicy.v1.Policy.ListPolicy)
            },
        ),
        "BooleanPolicy": _reflection.GeneratedProtocolMessageType(
            "BooleanPolicy",
            (_message.Message,),
            {
                "DESCRIPTOR": _POLICY_BOOLEANPOLICY,
                "__module__": "google.cloud.orgpolicy.v1.orgpolicy_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.orgpolicy.v1.Policy.BooleanPolicy)
            },
        ),
        "RestoreDefault": _reflection.GeneratedProtocolMessageType(
            "RestoreDefault",
            (_message.Message,),
            {
                "DESCRIPTOR": _POLICY_RESTOREDEFAULT,
                "__module__": "google.cloud.orgpolicy.v1.orgpolicy_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.orgpolicy.v1.Policy.RestoreDefault)
            },
        ),
        "DESCRIPTOR": _POLICY,
        "__module__": "google.cloud.orgpolicy.v1.orgpolicy_pb2"
        # @@protoc_insertion_point(class_scope:google.cloud.orgpolicy.v1.Policy)
    },
)
_sym_db.RegisterMessage(Policy)
_sym_db.RegisterMessage(Policy.ListPolicy)
_sym_db.RegisterMessage(Policy.BooleanPolicy)
_sym_db.RegisterMessage(Policy.RestoreDefault)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
